aboutsummaryrefslogtreecommitdiff
path: root/kernel/include/uapi/ethosu.h
diff options
context:
space:
mode:
Diffstat (limited to 'kernel/include/uapi/ethosu.h')
-rw-r--r--kernel/include/uapi/ethosu.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kernel/include/uapi/ethosu.h b/kernel/include/uapi/ethosu.h
index 699ef7e..4311186 100644
--- a/kernel/include/uapi/ethosu.h
+++ b/kernel/include/uapi/ethosu.h
@@ -67,7 +67,7 @@ namespace EthosU {
#define ETHOSU_PMU_EVENT_MAX 8
/* Kernel driver version */
-#define ETHOSU_KERNEL_DRIVER_VERSION_MAJOR 3
+#define ETHOSU_KERNEL_DRIVER_VERSION_MAJOR 4
#define ETHOSU_KERNEL_DRIVER_VERSION_MINOR 0
#define ETHOSU_KERNEL_DRIVER_VERSION_PATCH 0
@@ -194,16 +194,16 @@ struct ethosu_uapi_device_hw_id {
};
/**
* enum ethosu_dev_type - NPU device type
* @ETHOSU_DEV_UNKNOWN: Unknown NPU device type
* @ETHOSU_DEV_SUBSYSTEM: NPU managed by a subsystem communicated with via a
* mailbox
* @ETHOSU_DEV_DIRECT: NPU directly managed by the kernel driver
*/
-enum ethosu_dev_type {
- ETHOSU_DEV_UNKNOWN = 0,
- ETHOSU_DEV_SUBSYSTEM,
- ETHOSU_DEV_DIRECT,
+enum ethosu_uapi_device_type {
+ ETHOSU_UAPI_DEVICE_UNKNOWN = 0,
+ ETHOSU_UAPI_DEVICE_SUBSYSTEM,
+ ETHOSU_UAPI_DEVICE_DIRECT,
};
/**
@@ -194,16 +194,16 @@ struct ethosu_uapi_device_hw_id {
};
/**
- * enum ethosu_dev_type - NPU device type
- * @ETHOSU_DEV_UNKNOWN: Unknown NPU device type
- * @ETHOSU_DEV_SUBSYSTEM: NPU managed by a subsystem communicated with via a
- * mailbox
- * @ETHOSU_DEV_DIRECT: NPU directly managed by the kernel driver
+ * enum ethosu_uapi_device_type - NPU device type
+ * @ETHOSU_UAPI_DEVICE_UNKNOWN: Unknown NPU device type
+ * @ETHOSU_UAPI_DEVICE_SUBSYSTEM: NPU managed by a subsystem communicated with
+ * via a mailbox
+ * @ETHOSU_UAPI_DEVICE_DIRECT: NPU directly managed by the kernel driver
*/